<?php $TRANSLATIONS = array(
"Music" => "الموسيقى",
"songs" => "أغانى",
"albums" => "ألبومات",
"Add to playlist" => "اضف الى قائمة الأغاني",
"Add album to playlist" => "أضف الالبوم الى القائمه",
"Play" => "إلعب",
"Pause" => "تجميد",
"Previous" => "السابق",
"Next" => "التالي",
"Mute" => "إلغاء الصوت",
"Unmute" => "تشغيل الصوت",
"Rescan Collection" => "إعادة البحث عن ملفات الموسيقى",
"Artist" => "الفنان",
"Album" => "الألبوم",
"Title" => "العنوان"
);
